import excel "C:\IPT Data\Dataset.xlsx", sheet("Sheet1") firstrow
//Setting time variable
gen time=(CurrentTB_date- enrollment_date)/360
replace time=(last_visit_date-enrollment_date)/360 if TB=="No"
//Setting outcome variable
gen Outcome=0 if TB=="No"
replace Outcome=1 if TB=="Yes"
//Declaring survival data with ID variable
stset time, id(ID) failure(Outcome==1)
//Demarcating which records to split and at what time. Records will be split at time of ART initiation.
gen ARTtime=(ARTstartdate-enrollment_date)/360 if ARTinitiation=="Yes"
//Splitting the records
stsplit ART, at(0) after(_t=ARTtime)
replace ART = ART + 1
//Since only records still uncensored at time of splitting are split, outcome for the first 
//part of the records after splitting must be set to zero 
replace Outcome=0 if ART==1 & Outcome==.
//Again first part of the records that were 'split', that is patients on ART, must be set to zero, 
//or in this case, must be labled as 'PreART' since this is time they spent in 'PreART' or time before starting ART
replace ART=0 if ART==1 & ARTtime==.
//Splitting for patients in PreART and on IPT. Here, they patients spent in PreART while taking IPT is split
//from the time they were in PreART without IPT
gen IPTtime=(INH_date-enrollment_date)/360 if ARTinitiation=="No" & INH=="Yes"
stsplit IPTPre, at(0) after(_t=IPTtime)
replace IPTPre = IPTPre + 1
replace Outcome=0 if IPTPre==1 & Outcome==.
replace IPTPre=0 if IPTPre==1 & IPTtime==.
//Labeling patients on IPT-ART combination. 'IPTbeforetime' is time IPT was taken for patients who stsrted IPT
//during PreART care. Note also that patients who started IPT within 2 weeks of starting ART were labled as
//'IPTARTsimu' to mean IPT and ART started simultaneously.
gen IPTbeforetime=(INH_date-enrollment_date)/360 if ARTinitiation=="Yes" & INH=="Yes" & ART==0 & (ARTstartdate-INH_date)>14
//For patients who started IPT beofre ART, the period they took ART was labled as 'IPT before ART' 
gen IPTbeforeART=1 if ARTinitiation=="Yes" & INH=="Yes" & ART==1 & (ARTstartdate-INH_date)>14
gen IPTARTsimu=1 if ARTinitiation=="Yes" & INH=="Yes" & ART==1 & (ARTstartdate-INH_date)<=14 & (ARTstartdate-INH_date)>0
replace IPTARTsimu=1 if ARTinitiation=="Yes" & INH=="Yes" & ART==1 & (ARTstartdate-INH_date)>=-14 & (ARTstartdate-INH_date)<=0 
//Saving dataset upto this point before droping all records except PreART period records for 
//'IPT before ART' and 'IPT only' patinets and spliting it into 'PreART' and 'IPT only' groups
save "C:\IPT Data\temp\temp1.dta"
keep if ARTinitiation=="Yes" & INH=="Yes" & ART==0 & (ARTstartdate-INH_date)>14
stsplit IPTbefore, at(0) after(_t=IPTbeforetime)
replace IPTbefore = IPTbefore + 1
replace Outcome=0 if IPTbefore==1 & Outcome==.
replace IPTbefore=0 if IPTbefore==1 & IPTbeforetime==.
save "C:\IPT Data\temp\temp2.dta"
use "C:\IPT Data\temp\temp1.dta", clear
//Selecting patients who started IPT after 2 weeks on ART and splitting their time into time on 'ART only' 
//and time on 'IPT after ART' 
keep if ARTinitiation=="Yes" & INH=="Yes" & ART==1 & (ARTstartdate-INH_date)<-14
gen IPTaftertime=(INH_date-enrollment_date)/360
stsplit IPTafter, at(0) after(_t=IPTaftertime)
replace IPTafter = IPTafter + 1
replace Outcome=0 if IPTafter==1 & Outcome==.
replace IPTafter=0 if IPTafter==1 & IPTaftertime==.
save "C:\IPT Data\temp\temp3.dta"
//At this stage splitting observation times are completed. In the next steps, datasets temp2 and temp3 
//are appended back to the parent dataset. temp2 represents period patients were in PreART with and without IPT.
//In order to avoid duplication, first the PreART period for patients who took during PreART is dropped.    
use "C:\IPT Data\temp\temp1.dta", clear
drop if ARTinitiation=="Yes" & INH=="Yes" & ART==0 & (ARTstartdate-INH_date)>14
drop if ARTinitiation=="Yes" & INH=="Yes" & ART==1 & (ARTstartdate-INH_date)<-14
append using "C:\IPT Data\temp\temp2.dta", generate(append1)
append using "C:\IPT Data\temp\temp3.dta", generate(append2)
//A new variabl called 'Category' is created to identify the IPT and/or ART treatment recieved.
//Category=0 for period where neither IPT nor ART was recieved.
gen Category=0 if ART==0 & IPTPre!=1 & IPTbefore!=1
//Category=1 for period where IPT was recieved during PreART.
replace Category=1 if IPTPre==1 | IPTbefore==1
//Category=2 for period where ART was taken for patinets who took IPT during PreART.
replace Category=2 if IPTbeforeART==1
//Category=4 for period where patinets started and took both IPT and ART at the same time.
replace Category=4 if IPTARTsimu==1
//Category=5 for period where IPT was taken after starting ART.
replace Category=5 if IPTafter==1
//Category=3 for period where only ART was taken, not preceeded by IPT.
replace Category=3 if ART==1 & IPTafter!=1 & IPTbeforeART!=1 & IPTARTsimu!=1
//Since duplicate records were created while splitting person time of observation, data needs to be decalered 
//before doing survival analysis. Using the variable ID makes it possible for Stata to recognize and account
//for splitting observations of an individual. 
gen AGE=0 if age<15
replace AGE=1 if age>=15 & age<49
replace AGE=2 if age>=49
gen SEX=0 if sex=="Female"
replace SEX=1 if sex=="Male"
gen STAGE=0 if WHO_stage=="I or II"
replace STAGE=1 if WHO_stage=="III or IV"
gen CTX=0 if Cotrimoxazol=="No"
replace CTX=1 if Cotrimoxazol=="Yes"
gen CD4=0 if Baseline_CD4=="<100"
replace CD4=1 if Baseline_CD4=="100-199"
replace CD4=2 if Baseline_CD4=="200-349"
replace CD4=3 if Baseline_CD4==">349"
label define Category 0 "No IPT, No ART" 1 "IPT only" 2 "IPT before ART" 3 "ART only" 4 "IPT & ART simultaneously" 5 "IPT after ART"  
label values Category Category
//Median CD4 by treatment category
tabstat CD4_continous, statistics( mean median ) by(Category) columns(statistics)
stset time, id(ID) failure(Outcome==1) scale(1)
//Incidence, total
stptime
//Incidence by covariates
by AGE, sort : stptime
by SEX, sort : stptime
by CTX, sort : stptime
by STAGE, sort : stptime
by CD4, sort : stptime
by Category, sort : stptime
//Univariable analysis
stcox i.AGE, strata(Site)
stcox SEX, strata(Site)
stcox CTX, strata(Site)
stcox STAGE, strata(Site)
stcox i.CD4, strata(Site)
stcox i.Category, strata(Site)
//Multivariable analysis
stcox i.Category SEX CTX STAGE i.CD4, strata(Site)
//If one wants to run these codes again, it is better to delete temp files from 'temp' folder.
